@@ -1,17 +1,18 @@
-# Imports of packages:
-#' @import dplyr
-#' @import methods
-#' @import ggplot2
-#' @import parallel
-
 ################################################################################
 
 setClass("sim_fun",
-         slots = c(order = "numeric"),
+         slots = c(order = "numeric", call = "call"),
          contains = "function")
 
 ################################################################################
 
 setClass("sim_setup", 
          slots = c(base = "data.frame", simName = "character"), 
-         contains = "list")
\ No newline at end of file
+         contains = "list")
+
+setClass("summary.sim_setup",
+         slots = c(
+           sim_setup = "sim_setup",
+           duration = "table",
+           expression = "expression",
+           dim = "numeric"))
\ No newline at end of file
